==> ivy.angular.material.pagination-1.0.10.tgz: package/karma.conf.js <==
// Karma configuration
// Generated on Wed Mar 14 2018 15:19:36 GMT-0700 (US Mountain Standard Time)

var webpackConfig = require('./webpack.config')();

delete webpackConfig.entry;


module.exports = function(config) {
  config.set({

    // base path that will be used to resolve all patterns (eg. files, exclude)
    basePath: '',

    devtool: 'inline-source-map',

    // frameworks to use
    // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
    frameworks: ['jasmine'],


    // list of files / patterns to load in the browser
    files: [

        // My Files
        'test/index.ts',
    ],

    // preprocess matching files before serving them to the browser
    // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
    preprocessors: {
        'test/index.ts': ['webpack', 'sourcemap']
    },
    
    // Required for Firefox && Chrome
    mime: {
      'text/x-typescript': ['ts','tsx']
    },

    // test results reporter to use
    // possible values: 'dots', 'progress'
    // available reporters: https://npmjs.org/browse/keyword/karma-reporter
    reporters: ['progress', 'kjhtml'],


    // web server port
    port: 9876,


    // enable / disable colors in the output (reporters and logs)
    colors: true,


    // level of logging
    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
    logLevel: config.LOG_INFO,


    // enable / disable watching file and executing tests whenever any file changes
    autoWatch: false,


    // start these browsers
    // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
    //browsers: ['Chrome', 'Firefox', 'PhantomJS'],     // Local Testing
    //browsers: ['Chrome'],                             // Debugging
    browsers: ['PhantomJS'],                            // Committed for CI

    // Required for PhantomJS - the standard 10000ms is not enough
    browserNoActivityTimeout: 100000,

    // Continuous Integration mode
    // if true, Karma captures browsers, runs the tests and exits
    singleRun: false,

    // Concurrency level
    // how many browser should be started simultaneous
    concurrency: Infinity,

    webpack: webpackConfig,
  })
}

==> ivy.angular.material.pagination-1.1.3.tgz: package/karma.conf.js <==
// Karma configuration
// Generated on Wed Mar 14 2018 15:19:36 GMT-0700 (US Mountain Standard Time)

var webpackConfig = require('./webpack.config')();

delete webpackConfig.entry;


module.exports = function(config) {
  config.set({

    // base path that will be used to resolve all patterns (eg. files, exclude)
    basePath: '',

    devtool: 'inline-source-map',

    // frameworks to use
    // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
    frameworks: ['jasmine'],


    // list of files / patterns to load in the browser
    files: [

        // My Files
        'test/index.ts',
    ],

    // preprocess matching files before serving them to the browser
    // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
    preprocessors: {
        'test/index.ts': ['webpack', 'sourcemap']
    },
    
    // Required for Firefox && Chrome
    mime: {
      'text/x-typescript': ['ts','tsx']
    },

    // test results reporter to use
    // possible values: 'dots', 'progress'
    // available reporters: https://npmjs.org/browse/keyword/karma-reporter
    reporters: ['progress', 'kjhtml', 'bamboo'],


    // web server port
    port: 9876,


    // enable / disable colors in the output (reporters and logs)
    colors: true,


    // level of logging
    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
    logLevel: config.LOG_INFO,


    // enable / disable watching file and executing tests whenever any file changes
    autoWatch: false,


    // start these browsers
    // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
    //browsers: ['Chrome', 'Firefox', 'PhantomJS'],     // Local Testing
    //browsers: ['Chrome'],                             // Debugging
    browsers: ['PhantomJS'],                            // Committed for CI

    // Required for PhantomJS - the standard 10000ms is not enough
    browserNoActivityTimeout: 100000,

    // Continuous Integration mode
    // if true, Karma captures browsers, runs the tests and exits
    singleRun: true,

    // Concurrency level
    // how many browser should be started simultaneous
    concurrency: Infinity,

    webpack: webpackConfig,
  })
}
